@@ -4,5 +4,9 @@ from .thread_safe_event import ThreadSafeAsyncioEvent  # noqa: F401
 from .coro_runner import CoroutineRunner  # noqa: F401
 from .registry import Registry  # noqa: F401
 from .thread_exception import ExcThread  # noqa: F401
-from .thread_done_callback import ThreadDoneCallback  # noqa: F401
-from .task_done_callback import TaskDoneCallback  # noqa: F401
+from .done_callback import (  # noqa: F401
+    ThreadTaskDoneCallback,
+    ThreadDoneCallback,
+    TaskDoneCallback,
+)
+from .func import current_task_or_thread, to_thread  # noqa: F401
